In perl.git, the branch blead has been updated

<http://perl5.git.perl.org/perl.git/commitdiff/92683b8bd24649980234088f109e31c4633c1b67?hp=516cc7b3d537f089e725ceeb304dfb07583e516e>

- Log -----------------------------------------------------------------
commit 92683b8bd24649980234088f109e31c4633c1b67
Author: David Mitchell <[email protected]>
Date:   Tue Sep 27 15:13:56 2016 +0100

    Porting/bench.pl: explain what PUT means
    
    'PUT' is used in code comments, a function name, an error message, and
    verbose output; without ever saying what it stands for. Rectify this.

M       Porting/bench.pl

commit 9420b26806fca1f75d38f570e455d294af1c2fb6
Author: David Mitchell <[email protected]>
Date:   Tue Sep 27 14:50:25 2016 +0100

    Eliminate xpad_cop_seq from _xnvu union
    
    PVNV's used to be used to hold pad names (like '$lex'), but aren't used
    for this purpose any more. So eliminate the xpad_cop_seq part of the
    union.
    
    Since S_scan_subst() was using xnv_u.xpad_cop_seq.xlow to store a
    temporary line count, add a new union member for that.
    
    The main usage of this field on CPAN is to define
    COP_SEQ_RANGE_LOW()-style macros, so if the module is still using
    xpad_cop_seq for that purpose, it's already broken.

M       pad.c
M       sv.h
M       toke.c
-----------------------------------------------------------------------

Summary of changes:
 Porting/bench.pl | 7 ++++---
 pad.c            | 4 ++--
 sv.h             | 5 +----
 toke.c           | 4 ++--
 4 files changed, 9 insertions(+), 11 deletions(-)

diff --git a/pad.c b/pad.c
index bcbf95b..e810ccd 100644
--- a/pad.c
+++ b/pad.c
@@ -1066,8 +1066,8 @@ associated with the C<PARENT_FAKELEX_FLAGS> field of a 
fake pad name.
 Note that C<pad_findlex()> is recursive; it recurses up the chain of CVs,
 then comes back down, adding fake entries
 as it goes.  It has to be this way
-because fake names in anon protoypes have to store in C<xlow> the index into
-the parent pad.
+because fake names in anon protoypes have to store in C<xpadn_low> the
+index into the parent pad.
 
 =cut
 */
diff --git a/sv.h b/sv.h
index 07719a6..7f43f3b 100644
--- a/sv.h
+++ b/sv.h
@@ -487,10 +487,7 @@ perform the upgrade if necessary.  See C<L</svtype>>.
 union _xnvu {
     NV     xnv_nv;             /* numeric value, if any */
     HV *    xgv_stash;
-    struct {
-       U32 xlow;
-       U32 xhigh;
-    }      xpad_cop_seq;       /* used by pad.c for cop_sequence */
+    line_t  xnv_lines;           /* used internally by S_scan_subst() */
 };
 
 union _xivu {
diff --git a/toke.c b/toke.c
index 5fed84d..d44d36a 100644
--- a/toke.c
+++ b/toke.c
@@ -2493,7 +2493,7 @@ S_sublex_done(pTHX)
        }
        if (SvTYPE(PL_linestr) >= SVt_PVNV) {
            CopLINE(PL_curcop) +=
-               ((XPVNV*)SvANY(PL_linestr))->xnv_u.xpad_cop_seq.xlow
+               ((XPVNV*)SvANY(PL_linestr))->xnv_u.xnv_lines
                 + PL_parser->herelines;
            PL_parser->herelines = 0;
        }
@@ -9429,7 +9429,7 @@ S_scan_subst(pTHX_ char *start)
     }
     if (CopLINE(PL_curcop) != first_line) {
        sv_upgrade(PL_parser->lex_sub_repl, SVt_PVNV);
-       ((XPVNV*)SvANY(PL_parser->lex_sub_repl))->xnv_u.xpad_cop_seq.xlow =
+       ((XPVNV*)SvANY(PL_parser->lex_sub_repl))->xnv_u.xnv_lines =
            CopLINE(PL_curcop) - first_line;
        CopLINE_set(PL_curcop, first_line);
     }

diff --git a/Porting/bench.pl b/Porting/bench.pl
index fb06040..a2875a1 100755
--- a/Porting/bench.pl
+++ b/Porting/bench.pl
@@ -546,7 +546,8 @@ sub select_a_perl {
 
 
 # Validate the list of perl=label (+ cmdline options) on the command line.
 # Return a list of [ exe, label, cmdline-options ] tuples, ie PUTs
 
 sub process_puts {
     my @res_puts; # returned, each item is [ perlexe, label, @putargs ]
@@ -559,7 +560,7 @@ sub process_puts {
         my ($perl, $label, $env) = split /[=:,]/, $p, 3;
         $label //= $perl;
         $label = $perl.$label if $label =~ /^\+/;
-        die "$label cannot be used on 2 different PUTs\n" if $seen{$label}++;
+        die "$label cannot be used on 2 different perls under test\n" if 
$seen{$label}++;
 
         my %env;
         if ($env) {
@@ -572,7 +573,7 @@ sub process_puts {
             warn "Added Perl-Under-Test: [ @{[@{$res_puts[-1]}]} ]\n"
                 if $OPTS{verbose};
        } else {
-            warn "PUT-args: @putargs + a not-perl: $p $r\n"
+            warn "perl-under-test args: @putargs + a not-perl: $p $r\n"
                 if $OPTS{verbose};
             push @putargs, $p; # not-perl
        }
@@ -546,7 +546,8 @@ sub select_a_perl {
 
 # Validate the list of perl=label (+ cmdline options) on the command line.
-# Return a list of [ exe, label, cmdline-options ] tuples, ie PUTs
+# Return a list of [ exe, label, cmdline-options ] tuples, i.e.
+# 'perl-under-test's (PUTs)
 
 sub process_puts {
--
Perl5 Master Repository

Reply via email to